use strict;
use warnings;
package Task::Bootstrap::Perl::CPAN;
# git description: v0.002-1-g9c75d25

our $AUTHORITY = 'cpan:SCHWIGON';
# ABSTRACT: Dependencies for App::Bootstrap::Perl - CPAN bundle
$Task::Bootstrap::Perl::CPAN::VERSION = '0.003';

__END__

=pod

=encoding UTF-8

=head1 NAME

Task::Bootstrap::Perl::CPAN - Dependencies for App::Bootstrap::Perl - CPAN bundle

=head1 VERSION

version 0.003

=head1 TASK CONTENTS

=head2 cpan

=head3 L<Test::Simple>

=head3 L<List::MoreUtils>

=head3 L<version>

=head3 L<YAML::Syck>

=head3 L<IO::Tty>

=head3 L<LWP>

=head3 L<Expect>

=head3 L<ExtUtils::Config>

=head3 L<ExtUtils::MakeMaker>

=head3 L<Test::Harness>

=head3 L<ExtUtils::CBuilder>

=head3 L<File::Temp>

=head3 L<Test::More>

=head3 L<Data::Dumper>

=head3 L<IO::Compress::Base>

=head3 L<Compress::Zlib>

=head3 L<IO::Zlib>

=head3 L<Archive::Tar>

=head3 L<Module::Build>

=head3 L<File::Spec>

=head3 L<Digest::SHA>

=head3 L<File::HomeDir>

=head3 L<Archive::Zip>

=head3 L<Net::FTP>

=head3 L<Term::ReadKey>

=head3 L<Term::ReadLine::Perl>

=head3 L<YAML>

=head3 L<Parse::CPAN::Meta>

=head3 L<Text::Glob>

=head3 L<CPAN>

=head3 L<File::Which>

1;

=head1 AUTHOR

Steffen Schwigon <ss5@renormalist.net>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by Steffen Schwigon.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
